@@ -16,7 +16,12 @@ import aws_cdk.aws_sam._jsii
 import aws_cdk.core._jsii
 import constructs._jsii
 
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-secretsmanager", "1.49.0", __name__[0:-6], "aws-secretsmanager@1.49.0.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load(
+    "@aws-cdk/aws-secretsmanager",
+    "1.50.0",
+    __name__[0:-6],
+    "aws-secretsmanager@1.50.0.jsii.tgz",
+)
 
 __all__ = [
     "__jsii_assembly__",
